@@ -4,18 +4,17 @@ import (
 	"encoding/json"
 	"strings"
 
+	"github.com/prometheus/client_golang/prometheus"
+	"github.com/sirupsen/logrus"
+
 	corelisters "k8s.io/client-go/listers/core/v1"
 
-	"github.com/prometheus/client_golang/prometheus"
-
 	operatorv1 "github.com/openshift/api/operator/v1"
-
 	configv1 "github.com/openshift/api/samples/v1"
-	"github.com/openshift/cluster-samples-operator/pkg/client"
-	"github.com/openshift/cluster-samples-operator/pkg/util"
 	sampoplisters "github.com/openshift/client-go/samples/listers/samples/v1"
 
-	"github.com/sirupsen/logrus"
+	"github.com/openshift/cluster-samples-operator/pkg/client"
+	"github.com/openshift/cluster-samples-operator/pkg/util"
 )
 
 const (
@@ -25,6 +24,9 @@ const (
 	// we went with the _info suffix vs. the _total suffix
 	failedImportsQuery = "openshift_samples_failed_imagestream_import_info"
 
+	// the one current exception to the _info classficiation
+	importRetryQuery = "openshift_samples_retry_imagestream_import_total"
+
 	degradedQuery = "openshift_samples_degraded_info"
 
 	invalidConfigQuery = "openshift_samples_invalidconfig_info"
@@ -47,7 +49,7 @@ var (
 		[]string{"name"},
 		nil)
 	invalidSecretDesc = prometheus.NewDesc(invalidSecretQuery,
-		"Indicates if the pull secret is functional in the openshift namespace.  If not functional, the reason supplied either points to it missing in the openshift namesapce, or if it is missing credentials for registry.redhat.io when they should exist (1 == not functional, 0 == functional).",
+		"Indicates if the install pull secret is valid for pulling images from registry.redhat.io.  If invalid, the reason supplied either points to it being inaccessible, or if it is missing credentials for registry.redhat.io when they should exist (1 == not functional, 0 == functional).",
 		[]string{"reason"},
 		nil)
 	degradedStat = prometheus.NewGauge(prometheus.GaugeOpts{
@@ -62,6 +64,15 @@ var (
 		Name: tbrInaccessibleOnBootstrapQuery,
 		Help: "Indicates that during its initial installation the samples operator could not access registry.redhat.io and it boostrapped as removed.",
 	})
+	// looked into a imagestream name label on this metric but various prometheus guidance dissuaded that approach;
+	// looked into a constant metric like importsFailedDesc, but that requires more invasive changes to track the
+	// retry in our CRD;
+	// for now, with the failedImport metric having the name label, and this sanity check, we should get a sufficient validation that we
+	// are retrying - we can re-evaluate based on need and adoption in telemetry / OTA analysis / insights etc.
+	importRetryStat = prometheus.NewCounterVec(prometheus.CounterOpts{
+		Name: importRetryQuery,
+		Help: "Indicates the number of retries on imagestream import.",
+	}, []string{"imagestreamname"})
 
 	sc         = samplesCollector{}
 	registered = false
@@ -185,7 +196,7 @@ func addCountGauge(ch chan<- prometheus.Metric, desc *prometheus.Desc, name stri
 }
 
 func init() {
-	prometheus.MustRegister(degradedStat, configInvalidStat, tbrInaccessibleOnBootStat)
+	prometheus.MustRegister(degradedStat, configInvalidStat, tbrInaccessibleOnBootStat, importRetryStat)
 }
 
 func InitializeMetricsCollector(listers *client.Listers) {
